@@ -1,13 +1,11 @@
 OC.L10N.register(
     "notes",
     {
-    "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
-    "The notes folder is not accessible: %s" : "Mappen med noter er ikke tilgængelig: %s",
     "Error" : "Fejl",
     "New note" : "Ny note",
     "Notes" : "Noter",
-    "Settings" : "Indstillinger",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
+    "Settings" : "Indstillinger",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
     "Loading …" : "Indlæser…",
@@ -22,8 +20,8 @@ OC.L10N.register(
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
     "Details" : "Detaljer",
-    "Preview" : "Vis eksempel",
     "Edit" : "Redigér",
+    "Preview" : "Vis eksempel",
     "Category" : "Katergori",
     "Uncategorized" : "Udenfor kategori",
     "Saving failed!" : "Kunne ikke gemme!",
