@@ -8,7 +8,7 @@ OC.L10N.register(
     "Distraction-free notes and writing" : "Distraktionsfria anteckningar och skrivning",
     "Please see Nextcloud server log for details." : "Se Nextcloud serverlogg för mer information.",
     "Deleted {title}" : "Raderad {title}",
-    "Deleted {number} notes" : "Raderade {number} anteckningar",
+    "Deleted {number} notes" : "Borttagna {number} anteckningar",
     "Undo Delete" : "Ångra radering",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Det finns osparade anteckningar. Lämnas sidan kommer ändringarna förloras!",
     "Settings" : "Inställningar",
